You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vo...@apache.org on 2016/01/07 15:47:16 UTC

ignite git commit: IgniteHadoopIgfsSecondaryFileSystem.usrName field is renamed to "userName" to preserve backward compatibility.

Repository: ignite
Updated Branches:
  refs/heads/ignite-1.5.2 a12ec7d08 -> c786820dd


IgniteHadoopIgfsSecondaryFileSystem.usrName field is renamed to "userName" to preserve backward compatibility.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/c786820d
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/c786820d
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/c786820d

Branch: refs/heads/ignite-1.5.2
Commit: c786820dda7f7cd1849c5593ac24ca9072945887
Parents: a12ec7d
Author: vozerov-gridgain <vo...@gridgain.com>
Authored: Thu Jan 7 17:48:14 2016 +0400
Committer: vozerov-gridgain <vo...@gridgain.com>
Committed: Thu Jan 7 17:48:14 2016 +0400

----------------------------------------------------------------------
 .../ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java  | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/c786820d/modules/hadoop/src/main/java/org/apache/ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java
----------------------------------------------------------------------
diff --git a/modules/hadoop/src/main/java/org/apache/ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java b/modules/hadoop/src/main/java/org/apache/ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java
index 9f544c1..12cd2ac 100644
--- a/modules/hadoop/src/main/java/org/apache/ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java
+++ b/modules/hadoop/src/main/java/org/apache/ignite/hadoop/fs/IgniteHadoopIgfsSecondaryFileSystem.java
@@ -114,14 +114,14 @@ public class IgniteHadoopIgfsSecondaryFileSystem implements IgfsSecondaryFileSys
      *
      * @param uri URI of file system.
      * @param cfgPath Additional path to Hadoop configuration.
      * @param usrName User name.
      * @throws IgniteCheckedException In case of error.
      * @deprecated Use {@link #getFileSystemFactory()} instead.
      */
     @Deprecated
     public IgniteHadoopIgfsSecondaryFileSystem(@Nullable String uri, @Nullable String cfgPath,
-        @Nullable String usrName) throws IgniteCheckedException {
-        setDefaultUserName(usrName);
+        @Nullable String userName) throws IgniteCheckedException {
+        setDefaultUserName(userName);
 
         CachingHadoopFileSystemFactory fac = new CachingHadoopFileSystemFactory();
@@ -114,14 +114,14 @@ public class IgniteHadoopIgfsSecondaryFileSystem implements IgfsSecondaryFileSys
      * @param uri URI of file system.
      * @param cfgPath Additional path to Hadoop configuration.
-     * @param usrName User name.
+     * @param userName User name.
      * @throws IgniteCheckedException In case of error.
      * @deprecated Use {@link #getFileSystemFactory()} instead.